def get_ip(host):
    return host.ip_address()


def get_emails():
    return 'all users emails'


def get_gmail_password():
    return 'email password hacked!'


def sabotage():
    return 'can sabotage your friends internet connection'
